BrowserSessionFactory.CleanupTask (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class BrowserSessionFactory.CleanupTask

    java.lang.Object
      java.util.TimerTask
          org.openqa.selenium.server.BrowserSessionFactory.CleanupTask

All Implemented Interfaces:
  java.lang.Runnable

Enclosing class:
  BrowserSessionFactory

    protected class BrowserSessionFactory.CleanupTask

extends java.util.TimerTask

TimerTask that looks for unused sessions in the availableSessions collection.

Author:
  jbevan@google.com (Jennifer Bevan)

Constructor Summary
`protected` | `BrowserSessionFactory.CleanupTask()`

Method Summary
`void` | `run()`

Methods inherited from class java.util.TimerTask
`cancel, scheduledExecutionTime`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### BrowserSessionFactory.CleanupTask

    protected BrowserSessionFactory.CleanupTask()

Method Detail

### run

    public void run()

  Specified by:
    `run` in interface `java.lang.Runnable`
  Specified by:
    `run` in class `java.util.TimerTask`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.